get_zcta_crosswalk: Returns a ZCTA crosswalk as a tibble
Description
Returns the Census Bureau's 2020 ZCTA Country Relationship file
as a tibble. This function is included so that users can see how the crosswalk
was generated. It is not intended for use by end users.
Usage
get_zcta_crosswalk()
Arguments
Value
A tibble, where each row is a (zcta, county, state) combination.
See Also
All 2020 ZIP Code Tabulation Area 5-Digit (ZCTA5) Relationship Files: https://rb.gy/h0l5cs